==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/he-IL/admin/hardware/general.php <==
<?php

return [
    'about_assets_title'           => 'על נכסים',
    'about_assets_text'            => 'נכסים הם פריטים במעקב לפי מספר סידורי או תג נכס. הם נוטים להיות פריטים בעלי ערך גבוה יותר, כאשר מזהים פריטים ספציפיים.',
    'archived'  				=> 'בארכיון',
    'asset'  					=> 'נכס',
    'bulk_checkout'             => 'שייך נכס',
    'bulk_checkin'              => 'החזר נכסים לזמינות',
    'checkin'  					=> 'רכוש',
    'checkout'  				=> 'רכוש Checkout',
    'clone'  					=> 'נכס משוכפל',
    'deployable'  				=> 'ניתן לפריסה',
    'deleted'  					=> 'הנכס הזה נמחק.',
    'delete_confirm'            => 'Are you sure you want to delete this asset?',
    'edit'  					=> 'ערוך נכס',
    'model_deleted'  			=> 'המודל של הנכס נמחק. יש לשחזר את המודל לפני שניתן לשחזר את הנכס.',
    'model_invalid'             => 'This model for this asset is invalid.',
    'model_invalid_fix'         => 'The asset must be updated use a valid asset model before attempting to check it in or out, or to audit it.',
    'requestable'               => 'ניתן לבקש',
    'requested'				    => 'מבוקש',
    'not_requestable'           => 'Not Requestable',
    'requestable_status_warning' => 'Do not change requestable status',
    'restore'  					=> 'שחזור נכס',
    'pending'  					=> 'ממתין ל',
    'undeployable'  			=> 'לא ניתן לפריסה',
    'undeployable_tooltip'  	=> 'This asset has a status label that is undeployable and cannot be checked out at this time.',
    'view'  					=> 'הצג נכס',
    'csv_error' => 'קיימת שגיאה בקובץ ה-CSV שלך:',
    'import_text' => '<p>Upload a CSV that contains asset history. The assets and users MUST already exist in the system, or they will be skipped. Matching assets for history import happens against the asset tag. We will try to find a matching user based on the user\'s name you provide, and the criteria you select below. If you do not select any criteria below, it will simply try to match on the username format you configured in the <code>Admin &gt; General Settings</code>.</p><p>Fields included in the CSV must match the headers: <strong>Asset Tag, Name, Checkout Date, Checkin Date</strong>. Any additional fields will be ignored. </p><p>Checkin Date: blank or future checkin dates will checkout items to associated user.  Excluding the Checkin Date column will create a checkin date with todays date.</p>
    ',
    'csv_import_match_f-l' => 'Try to match users by <strong>firstname.lastname</strong> (<code>jane.smith</code>) format',
    'csv_import_match_initial_last' => 'Try to match users by <strong>first initial last name</strong> (<code>jsmith</code>) format',
    'csv_import_match_first' => 'Try to match users by <strong>first name</strong> (<code>jane</code>) format',
    'csv_import_match_email' => 'Try to match users by <strong>email</strong> as username',
    'csv_import_match_username' => 'Try to match users by <strong>username</strong>',
    'error_messages' => 'שגיאות:',
    'success_messages' => 'אישור:',
    'alert_details' => 'נא ראה הסבר בהמשך.',
    'custom_export' => 'יבוא מותאם',
    'mfg_warranty_lookup' => ':manufacturer Warranty Status Lookup',
    'user_department' => 'מחלקת משתמשים',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/he-IL/admin/hardware/general.php <==
<?php

return [
    'about_assets_title'           => 'על נכסים',
    'about_assets_text'            => 'נכסים הם פריטים במעקב לפי מספר סידורי או תג נכס. הם נוטים להיות פריטים בעלי ערך גבוה יותר, כאשר מזהים פריטים ספציפיים.',
    'archived'  				=> 'בארכיון',
    'asset'  					=> 'נכס',
    'bulk_checkout'             => 'יציאה גורפת',
    'bulk_checkin'              => 'Bulk Checkin',
    'checkin'  					=> 'רכוש',
    'checkout'  				=> 'רכוש Checkout',
    'clone'  					=> 'נכס משוכפל',
    'deployable'  				=> 'ניתן לפריסה',
    'deleted'  					=> 'הנכס הזה נמחק.',
    'delete_confirm'            => 'Are you sure you want to delete this asset?',
    'edit'  					=> 'ערוך נכס',
    'model_deleted'  			=> 'המודל של הנכס נמחק. יש לשחזר את המודל לפני שניתן לשחזר את הנכס.',
    'model_invalid'             => 'This model for this asset is invalid.',
    'model_invalid_fix'         => 'The asset must be updated use a valid asset model before attempting to check it in or out, or to audit it.',
    'requestable'               => 'ניתן לבקש',
    'requested'				    => 'מבוקש',
    'not_requestable'           => 'Not Requestable',
    'requestable_status_warning' => 'Do not change requestable status',
    'restore'  					=> 'שחזור נכס',
    'pending'  					=> 'ממתין ל',
    'undeployable'  			=> 'לא ניתן לפריסה',
    'undeployable_tooltip'  	=> 'This asset has a status label that is undeployable and cannot be checked out at this time.',
    'view'  					=> 'הצג נכס',
    'csv_error' => 'קיימת שגיאה בקובץ ה-CSV שלך:',
    'import_text' => '<p>Upload a CSV that contains asset history. The assets and users MUST already exist in the system, or they will be skipped. Matching assets for history import happens against the asset tag. We will try to find a matching user based on the user\'s name you provide, and the criteria you select below. If you do not select any criteria below, it will simply try to match on the username format you configured in the <code>Admin &gt; General Settings</code>.</p><p>Fields included in the CSV must match the headers: <strong>Asset Tag, Name, Checkout Date, Checkin Date</strong>. Any additional fields will be ignored. </p><p>Checkin Date: blank or future checkin dates will checkout items to associated user.  Excluding the Checkin Date column will create a checkin date with todays date.</p>
    ',
    'csv_import_match_f-l' => 'Try to match users by <strong>firstname.lastname</strong> (<code>jane.smith</code>) format',
    'csv_import_match_initial_last' => 'Try to match users by <strong>first initial last name</strong> (<code>jsmith</code>) format',
    'csv_import_match_first' => 'Try to match users by <strong>first name</strong> (<code>jane</code>) format',
    'csv_import_match_email' => 'Try to match users by <strong>email</strong> as username',
    'csv_import_match_username' => 'Try to match users by <strong>username</strong>',
    'error_messages' => 'שגיאות:',
    'success_messages' => 'אישור:',
    'alert_details' => 'נא ראה הסבר בהמשך.',
    'custom_export' => 'יבוא מותאם',
    'mfg_warranty_lookup' => ':manufacturer Warranty Status Lookup',
    'user_department' => 'מחלקת משתמשים',
];
